# Claudebook

`claudebook` is a little wrapper around `claude` ([Claude Code](https://docs.claude.com/en/docs/claude-code/overview)) which runs a
markdown file (with some nicities).

The idea is to make Claude-o-matable runbooks.
